###################################################################################################
# zmsteaserelement.py
#
# Implementation of class ZMSTeaserElement (see below).
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
###################################################################################################

# Imports.
from Globals import HTML, HTMLFile
from OFS.Folder import Folder
import string 
import urllib
import time
# Product Imports.
from zmsobject import ZMSObject
import _zcatalogmanager
import _globals
import _linklib
import _blobfields


###################################################################################################
###################################################################################################
###   
###   C o n s t r u c t o r ( s )
###   
###################################################################################################
###################################################################################################

def manage_addZMSTeaserElement(self, lang, manage_lang, _sort_id, REQUEST):
  """ manage_addZMSTeaserElement """
  
  ##### Create ####
  obj = ZMSTeaserElement(self.getNewId(),_sort_id+1)
  self._setObject(obj.id, obj)
    
  for oItem in self.objectValues():
    if oItem.id == obj.id:
      ##### VersionManager ####
      oItem.setObjStateNew(REQUEST)
      ##### Init Properties ####
      for s_lang in self.getLanguages():
        oItem.setObjProperty('active',1,s_lang)
      ##### VersionManager ####
      oItem.__autoCommit__(REQUEST)
            
  ##### Normalize Sort-IDs ####
  self.normalizeSortIds()
        
  # Return with message.        
  if REQUEST.RESPONSE:
    message = self.getLangStr('MSG_INSERTED',manage_lang)%obj.display_type(REQUEST)
    REQUEST.RESPONSE.redirect('%s/%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(self.absolute_url(),obj.id,lang,manage_lang,urllib.quote(message)))


###################################################################################################

lstPenetrance = [
  0,'this',
  1,'sub_nav',
  2,'sub_all'
]

###################################################################################################
###################################################################################################
###   
###   C l a s s
###   
###################################################################################################
###################################################################################################

class ZMSTeaserElement(ZMSObject, Folder): 
        
    # Properties.
    # -----------
    meta_type = "ZMSTeaserElement"
    icon_disabled = "misc_/zms/zmsteaser_disabled.gif"

    # Management Options.
    # -------------------
    manage_options = ( 
	{'label': 'TAB_EDIT', 'action': 'manage_main'},
	)

    # Management Permissions.
    # -----------------------
    __authorPermissions__ = (
		'manage','manage_main','manage_menu',
		'manage_properties','manage_changeProperties',
		'manage_moveObjUp','manage_moveObjDown',
		'manage_cutObjects','manage_copyObjects','manage_pasteObjs',
		'manage_rollbackVersionChanges','manage_requestVersionChanges',
		)
    __editorPermissions__ = (
		'manage_commitVersionChanges',
		)
    __administratorPermissions__ = (
		)
    __ac_permissions__=(
		('ZMS Author', __authorPermissions__),
		('ZMS Editor', __editorPermissions__),
		('ZMS Administrator', __administratorPermissions__),
		('Import/Export objects', ('manage_importexport','manage_import','manage_export',) ),
		)

    # Properties.
    # -----------
    __obj_attrs__ = {
        'sort_id':{'datatype':'string','native':1},
        'change_uid':{'datatype':'LangString','lang_inherit':-1},
        'change_dt':{'datatype':'LangDate','lang_inherit':-1},
        'active':{'datatype':'LangInt','type':'checkbox','lang_inherit':0},
        'attr_active_start':{'datatype':'LangDate','lang_inherit':0},
        'attr_active_end':{'datatype':'LangDate','lang_inherit':0},
        'title':{'datatype':'LangString','size':40},
        'text':{'datatype':'LangString','type':'textarea','size':40},
        'textalign':{'datatype':'string','default':'LEFT'},
        'displaytype':{'datatype':'int','default':2},
        'attr_penetrance':{'datatype':'int','type':'select','options':lstPenetrance},
        'attr_url':{'datatype':'LangString'},
        'attr_img':{'datatype':'LangMyImage'},
    }


    # Management Interface.
    manage_main = HTMLFile('dtml/zmsteaserelement/manage_main',globals()) 


    """
    ###############################################################################################    
    #
    #   CONSTRUCTOR
    #
    ###############################################################################################    
    """

    ###############################################################################################
    # ZMSTeaserElement.recurse_updateVersion:
    #
    # Update version.
    ###############################################################################################
    def recurse_updateVersion(self, lang, manage_lang, REQUEST):
      message = ''

      # Process super-objects.
      message = message + ZMSObject.recurse_updateVersion(self,lang,manage_lang,REQUEST)
        
      # Process object.
      # [...]
            
      # ---------------------------------------------------------------------
      # 11.01.2002 - 0.9 to 1.0: 
      # Blobs.
      # ---------------------------------------------------------------------
      _blobfields.synchronizeBlobFields(self)

      # ---------------------------------------------------------------------
      # 26.02.2002
      # Build #067: Activity-Toggle.
      # ---------------------------------------------------------------------
      for s_preview in [None,'preview']:
        req = {'preview':s_preview}
        ob = self.getObjVersion(req)
        for s_key in ['active']:
          for s_lang in self.getLanguages():
            attr = '%s_%s'%(s_key,s_lang)
            if not hasattr(ob,attr) or getattr(self,'build','') <= '067':
              active = getattr(ob,'attr_active_start_%s'%s_lang,None) is not None or \
                       getattr(ob,'attr_active_end_%s'%s_lang,None) is not None 
              #++ print "[%s.recurse_updateVersion]: Activity-Toggle %s.%s=%i"%(self.meta_type,str(ob),attr,active)
              setattr(ob,attr,active)
      
      # Return with message.
      return message


    """
    ###############################################################################################    
    #
    #   Eigenschaften
    #
    ###############################################################################################    
    """

    ###############################################################################################
    #  ZMSTeaserElement.manage_changeProperties: 
    #
    #  Change Teaser properties.
    ###############################################################################################
    def manage_changeProperties(self, lang, manage_lang, REQUEST): 
        """ ZMSTeaserElement.manage_changeProperties """
        
        if REQUEST.has_key('btn') and REQUEST['btn'] == self.getLangStr('BTN_CANCEL',manage_lang):
          return REQUEST.RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s#%s'%(self.getParentNode().absolute_url(),lang,manage_lang,self.id))
        
        ##### Object State #####
        self.setObjStateModified(REQUEST)
            
        ##### Properties #####
        self.setReqProperty('title',REQUEST)
        self.setReqProperty('text',REQUEST)
        self.setReqProperty('textalign',REQUEST)
        self.setReqProperty('displaytype',REQUEST)
        self.setReqProperty('attr_penetrance',REQUEST)
        self.setReqProperty('attr_url',REQUEST)
        self.setReqProperty('attr_img',REQUEST)
        # Active.
        self.setReqProperty('active',REQUEST)
        self.setReqProperty('attr_active_start',REQUEST)
        self.setReqProperty('attr_active_end',REQUEST)

        ##### Blobs #####
        _blobfields.synchronizeBlobFields(self)
          
        ##### VersionManager ####
        self.__autoCommit__(REQUEST)
          
	##### Message #####
        message = self.getLangStr('MSG_CHANGED',manage_lang)
        
        # Return with message.
    	self.checkIn(REQUEST)
        REQUEST.RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s#_%s'%(self.getParentNode().absolute_url(),lang,manage_lang,urllib.quote(message),self.id))


    # ---------------------------------------------------------------------------------------------
    #	ZMSTeaserElement.getText
    #	ZMSTeaserElement.getTitle
    #	ZMSTeaserElement.getAbstract
    #	ZMSTeaserElement.getImg
    #	ZMSTeaserElement.getUrl
    # ---------------------------------------------------------------------------------------------
    def getText(self, REQUEST): return self.getObjProperty('text',REQUEST)
    def getTitle(self, REQUEST): return self.getObjProperty('title',REQUEST)
    def getAbstract(self, REQUEST): return _zcatalogmanager.search_quote(self.getText(REQUEST))
    def getImg(self, REQUEST): return self.getObjProperty('attr_img',REQUEST)
    def getUrl(self, REQUEST): return _linklib.getUrl(self,'attr_url',REQUEST)


    # ---------------------------------------------------------------------------------------------
    #	ZMSTeaserElement.isActive:
    # ---------------------------------------------------------------------------------------------
    def isActive(self,REQUEST): 
      rtn = self.getObjProperty('active',REQUEST)
      if rtn:
        #-- Init time.
        t0 = time.time()        
        #-- Start.  
        t1 = self.getObjProperty('attr_active_start',REQUEST)
        if t1 is not None:
          rtn = rtn and _globals.compareDate(t1,t0) >= 0
        #-- End.  
        t1 = self.getObjProperty('attr_active_end',REQUEST)
        if t1 is not None:
          rtn = rtn and _globals.compareDate(t1,t0) < 1
      return rtn


    # ---------------------------------------------------------------------------------------------
    #	ZMSTeaserElement.getTitlealt:
    # ---------------------------------------------------------------------------------------------
    def getTitlealt(self,REQUEST): return self.display_type(REQUEST)


    """
    ###############################################################################################    
    ###  
    ###  HTML-Darstellung 
    ### 
    ###############################################################################################    
    """    

    # preload display interface
    rendershort_default = HTMLFile('dtml/zmsteaserelement/rendershort_default', globals()) 
    
    ###############################################################################################    
    #  ZMSTeaserElement.renderShort:
    #
    #  Renders short presentation of Teaser-Element.
    ###############################################################################################    
    def renderShort(self, REQUEST):
        html = ''
        # Retrieve properties.
        s_title = self.getTitle(REQUEST)
        #-- STEP 1
        # Retrieve properties.
        displaytype  = self.getObjProperty('displaytype',REQUEST,2)
        imgattr      = 'attr_img'
        imghiresattr = None
        imgalign     = self.getObjProperty('textalign',REQUEST,'LEFT')
        imgurl       = self.getUrl(REQUEST)
        imgtarget    = ''
        imgthumb     = 1
        imgspecial   = ''
        imgclass     = None
        textalign    = self.getObjProperty('textalign',REQUEST)
        textformat   = None
        textclass    = "teaserTitle"
        text         = s_title
        if imgurl: 
          if not string.find(imgurl,self.getDocumentElement().absolute_url()) == 0:
            imgtarget = ' target="_blank"'
          text = '<a href="%s"%s class="teaserTitle">%s</a>'%(imgurl,imgtarget,text)
        text = '<p class="%s">%s</p>'%(textclass,text)
        # Render <html>-presentation.
        html = self.renderDisplaytype(displaytype,imgattr,imghiresattr,imgalign,imgurl,imgthumb,imgspecial,imgclass,text,textalign,textformat,textclass,REQUEST)
        #-- STEP 2
        # Retrieve properties.
        url = imgurl
        target = imgtarget
        title = html
        text = self.getText(REQUEST)
        textclass   = "teaserText"
        img = self.getImg(REQUEST)
        oTeaserContainer = self.getParentNode()
        bgcolor_title = oTeaserContainer.getObjProperty('attr_bgcolor_title',REQUEST)
        if REQUEST.has_key('bgcolor_title'):
          bgcolor_title = REQUEST['bgcolor_title']
        bgcolor_text = oTeaserContainer.getObjProperty('attr_bgcolor_text',REQUEST)
        if REQUEST.has_key('bgcolor_text'):
          bgcolor_text = REQUEST['bgcolor_text']
        # Render <html>-presentation.
        if img is not None and \
           img.get_size() > 0 and \
           len(s_title) == 0:
          imgclass = bgcolor_title
          html = '<table cellspacing="0" cellpadding="0" border="0"'
          if bgcolor_text:
            html = html + 'class="%s"'%bgcolor_text
          html = html + '>'
          html = html + '<tr>'
          html = html + '<td align="%s">%s</td>'%(textalign,self.renderDisplaytype(displaytype,imgattr,imghiresattr,imgalign,imgurl,imgthumb,imgspecial,imgclass,text,textalign,textformat,textclass,REQUEST))
          html = html + '</tr>'
          html = html + '</table>'
        else:
          html = self.rendershort_default(self,ob=self,url=url,target=target,title=title,text=text,img=img,displaytype=displaytype,bgcolor_title=bgcolor_title,bgcolor_text=bgcolor_text,REQUEST=REQUEST)
        # Return <html>-presentation.
        return html

    ###############################################################################################    
    #	ZMSTeaserElement.catalogText:
    #
    #	Catalog text of Teaser-Element.
    ###############################################################################################    
    def catalogText(self, REQUEST):
      s = ""
      s = s + self.getTitle(REQUEST) + " "
      s = s + self.getText(REQUEST) +  " "
      return s

###################################################################################################
